"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var ApplicationInsightsInstance = require("applicationinsights");
var Validation_1 = require("./utils/Validation");
var datacontracts_1 = require("./datacontracts");
exports.BaseEvent = datacontracts_1.BaseEvent;
exports.BpmValidation = datacontracts_1.BpmValidation;
exports.ComponentType = datacontracts_1.ComponentType;
exports.CorrelationConstants = datacontracts_1.CorrelationConstants;
exports.ExtensionsConfig = datacontracts_1.ExtensionsConfig;
exports.ItEventType = datacontracts_1.ItEventType;
exports.ItTelemetryConfiguration = datacontracts_1.ItTelemetryConfiguration;
exports.SerializationHelper = datacontracts_1.SerializationHelper;
exports.BusinessProcessEvent = datacontracts_1.BusinessProcessEvent;
exports.FeatureUsageEvent = datacontracts_1.FeatureUsageEvent;
exports.SystemEvent = datacontracts_1.SystemEvent;
exports.EnvironmentValues = datacontracts_1.EnvironmentValues;
var version = process.env.npm_package_version;
var UTPTelemetry = /** @class */ (function () {
    function UTPTelemetry(instrumentationKey, environment) {
        if (Validation_1.Validation.InstrumentationKey(instrumentationKey)) {
            this.telemetryInstance = new ApplicationInsightsInstance.TelemetryClient(instrumentationKey);
            this.telemetryInstance.commonProperties = environment.getTelemetryObject(instrumentationKey, "UTP-Node-JS-SDK-" + version);
            console.log(version);
        }
        else {
            console.error("Validation check failed, please check if you have given a valid Instrumentation Key");
        }
    }
    UTPTelemetry.prototype.TrackTrace = function (traceMessage, severity) {
        if (severity === void 0) { severity = null; }
        if (traceMessage && traceMessage.length > 0) {
            this.telemetryInstance.trackTrace({ message: traceMessage, severity: severity });
            return true;
        }
        console.log("Trace message cannot be empty ");
        return false;
    };
    UTPTelemetry.prototype.TrackEvent = function (eventName) {
        if (eventName && eventName.length > 0) {
            this.telemetryInstance.trackEvent({ name: eventName });
            return true;
        }
        console.log("Event name cannot be empty ");
        return false;
    };
    UTPTelemetry.prototype.TrackMetric = function (metricName, metricValue, metricCount, minValue, maxValue, stdDev) {
        if (metricName && metricName.length > 0) {
            this.telemetryInstance.trackMetric({ name: metricName, value: metricValue, count: metricCount,
                min: minValue, max: maxValue, stdDev: stdDev });
            return true;
        }
        console.log("Metric name cannot be empty ");
        return false;
    };
    UTPTelemetry.prototype.TrackRequest = function (requestName, requestUrl, requestDuration, requestResultCode, isRequestSuccess, requestSource) {
        if (requestName && requestName.length > 0) {
            this.telemetryInstance.trackRequest({ name: requestName, url: requestUrl, duration: requestDuration,
                resultCode: requestResultCode, success: isRequestSuccess, source: requestSource });
            return true;
        }
        console.log("Request name cannot be empty ");
        return false;
    };
    UTPTelemetry.prototype.TrackDependency = function (dependencyName, dependencyTypeName, dependencyData, dependencyDuration, dependencyResultCode, isSuccess, dependencyTarget) {
        if (dependencyName && dependencyName.length > 0) {
            this.telemetryInstance.trackDependency({ name: dependencyName, dependencyTypeName: dependencyTypeName, data: dependencyData,
                duration: dependencyDuration, resultCode: dependencyResultCode, success: isSuccess, target: dependencyTarget });
            return true;
        }
        console.log("Dependency name cannot be empty ");
        return false;
    };
    UTPTelemetry.prototype.TrackException = function (exceptionMessage, exeptionMesaurements) {
        if (exceptionMessage && exceptionMessage.length > 0) {
            this.telemetryInstance.trackException({ exception: new Error(exceptionMessage), measurements: exeptionMesaurements });
            return true;
        }
        console.log("Exception name cannot be empty ");
        return false;
    };
    UTPTelemetry.prototype.TrackFeatureUsageEvent = function (featureUsageEventData) {
        if (featureUsageEventData.IsValidEvent()) {
            var telemetryObject = featureUsageEventData.getTelemtryObject();
            this.telemetryInstance.trackEvent({ name: featureUsageEventData.EventName, properties: telemetryObject });
            return true;
        }
        else {
            console.log("Please give a valid event name");
            return false;
        }
    };
    UTPTelemetry.prototype.TrackBusinessProcessEvent = function (bussinessProcessEventData) {
        if (bussinessProcessEventData.IsValidEvent()) {
            var telemetryObject = bussinessProcessEventData.getTelemetryObject();
            this.telemetryInstance.trackEvent({ name: bussinessProcessEventData.EventName, properties: telemetryObject });
            return true;
        }
        else {
            console.log("Mandatory fields appAction, businessProcessName, receiverId, senderId, eventOccurenceTime");
            return false;
        }
    };
    UTPTelemetry.prototype.TrackSystemEvent = function (systemEventData) {
        if (systemEventData.IsValidEvent()) {
            var telemetryObject = systemEventData.getTelemetryObject();
            this.telemetryInstance.trackEvent({ name: systemEventData.EventName, properties: telemetryObject });
            return true;
        }
        else {
            console.log("Please give a valid event name");
            return false;
        }
    };
    return UTPTelemetry;
}());
exports.UTPTelemetry = UTPTelemetry;
//# sourceMappingURL=UTPTelemetry.js.map