"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var assert = require("assert");
var sinon = require("sinon");
var EnvironmentValues_1 = require("../datacontracts/EnvironmentValues");
var FeatureUsageEvent_1 = require("../datacontracts/FeatureUsageEvent");
var BusinessProcessEvent_1 = require("../datacontracts/BusinessProcessEvent");
var SystemEvent_1 = require("../datacontracts/SystemEvent");
var ComponentType_1 = require("../datacontracts/ComponentType");
describe("UTPTelemetry", function () {
    var UTPTelemetry = require("../UTPTelemetry");
    var UTPTelemetryInstance = undefined;
    var validEnvironmentValues = undefined;
    var invalidEnvironmentValues = undefined;
    var validTelemetryInstance = undefined;
    var invalidTelemetryInstance = undefined;
    beforeEach('Arrange all the dependencies', function () {
        invalidEnvironmentValues = new EnvironmentValues_1.EnvironmentValues('Production', 'ServiceOffering', 'ServiceLine', 'Service', 'UTPComponent', '', '');
        validEnvironmentValues = new EnvironmentValues_1.EnvironmentValues('Production', 'ServiceOffering', 'ServiceLine', 'Service', 'UTPComponent', 'some-random-guid', 'some-random-guid');
        validTelemetryInstance = new UTPTelemetry.UTPTelemetry('some-random-guid', validEnvironmentValues);
        invalidTelemetryInstance = new UTPTelemetry.UTPTelemetry('', invalidEnvironmentValues);
    });
    afterEach(function () {
    });
    it('check for valid dependency data', function () {
        var logStub = sinon.stub(console, 'log');
        UTPTelemetryInstance = new UTPTelemetry.UTPTelemetry('some-random-guid', validEnvironmentValues);
        assert.ok(logStub.called);
    });
    it('check for invalid dependency data', function () {
        var errorStub = sinon.stub(console, 'error');
        UTPTelemetryInstance = new UTPTelemetry.UTPTelemetry('', validEnvironmentValues);
        assert.ok(errorStub.called);
    });
    it('TrackTrace with valid data', function () {
        var status = validTelemetryInstance.TrackTrace("Trace message");
        assert.equal(status, true);
    });
    it('TrackTrace with in-valid data', function () {
        var status = validTelemetryInstance.TrackTrace("");
        assert.equal(status, false);
    });
    it('TrackEvent with valid data', function () {
        var status = validTelemetryInstance.TrackEvent("Track message");
        assert.equal(status, true);
    });
    it('TrackEvent with in-valid data', function () {
        var status = validTelemetryInstance.TrackEvent("");
        assert.equal(status, false);
    });
    it('TrackMetric with valid data', function () {
        var status = validTelemetryInstance.TrackMetric("Metric message", 2, 2);
        assert.equal(status, true);
    });
    it('TrackMetric with in-valid data', function () {
        var status = validTelemetryInstance.TrackMetric("", 2, 2);
        assert.equal(status, false);
    });
    it('TrackRequest with valid data', function () {
        var status = validTelemetryInstance.TrackRequest("Request message", "http://mockurl", 5, "502", false);
        assert.equal(status, true);
    });
    it('TrackRequest with in-valid data', function () {
        var status = validTelemetryInstance.TrackRequest("", "http://mockurl", 5, "502", false);
        assert.equal(status, false);
    });
    it('TrackDependency with valid data', function () {
        var status = validTelemetryInstance.TrackDependency("Dependency message", "Type", "Data", 5, "502", true);
        assert.equal(status, true);
    });
    it('TrackDependency with in-valid data', function () {
        var status = validTelemetryInstance.TrackDependency("", "Type", "Data", 5, "502", true);
        assert.equal(status, false);
    });
    it('TrackException with valid data', function () {
        var status = validTelemetryInstance.TrackException("ExceptionName", "Message", "stack");
        assert.equal(status, true);
    });
    it('TrackException with in-valid data', function () {
        var status = validTelemetryInstance.TrackException("", "Message", "stack");
        assert.equal(status, false);
    });
    it('TrackFeatureUsageEvent with valid data', function () {
        var featureEvent = new FeatureUsageEvent_1.FeatureUsageEvent("FeatureEvent", ComponentType_1.ComponentType.Device);
        var status = validTelemetryInstance.TrackFeatureUsageEvent(featureEvent);
        assert.equal(status, true);
    });
    it('TrackFeatureUsageEvent with in-valid data', function () {
        var featureEvent = new FeatureUsageEvent_1.FeatureUsageEvent("", ComponentType_1.ComponentType.Device);
        var status = validTelemetryInstance.TrackFeatureUsageEvent(featureEvent);
        assert.equal(status, false);
    });
    it('TrackBusinessProcessEvent with valid data', function () {
        var businessEvent = new BusinessProcessEvent_1.BusinessProcessEvent("BusinessProcessEvent", ComponentType_1.ComponentType.Device);
        businessEvent.AppAction = "AppAction";
        businessEvent.ReceiverId = "ReceiverId";
        businessEvent.SenderId = "SenderId";
        businessEvent.EventOccurrenceTime = new Date();
        var status = validTelemetryInstance.TrackBusinessProcessEvent(businessEvent);
        assert.equal(status, true);
        ;
    });
    it('TrackBusinessProcessEvent with in-valid data', function () {
        var businessEvent = new BusinessProcessEvent_1.BusinessProcessEvent("", ComponentType_1.ComponentType.Device);
        var status = validTelemetryInstance.TrackBusinessProcessEvent(businessEvent);
        assert.equal(status, false);
    });
    it('TrackSystemEvent with valid data', function () {
        var systemEvent = new SystemEvent_1.SystemEvent("SystemEvent", ComponentType_1.ComponentType.Device);
        var status = validTelemetryInstance.TrackSystemEvent(systemEvent);
        assert.equal(status, true);
    });
    it('TrackSystemEvent with in-valid data', function () {
        var systemEvent = new SystemEvent_1.SystemEvent("", ComponentType_1.ComponentType.Device);
        var status = validTelemetryInstance.TrackSystemEvent(systemEvent);
        assert.equal(status, false);
    });
});
//# sourceMappingURL=UTPTelemetry.test.js.map